@@ -271,6 +271,7 @@ class API:
         status: str = "inprogress",
         send_email: bool = True,
         worker_number: int = None,
+        output: dict = None,
     ):
         # add edge case for API
         if job_id == "":
@@ -281,32 +282,25 @@ class API:
             )
         if metadata is None:
             metadata = {}
+        parameters = dict(
+            metadata=metadata,
+            status=status,
+            workflow_name=workflow_name,
+            additional_information=additional_information,
+            send_email=send_email,
+        )
         if worker_number is None:
-            return requests.post(
-                url=self._base_url + f"/workflows/{job_id}/status",
-                headers=self._headers,
-                json=dict(
-                    metadata=metadata,
-                    status=status,
-                    workflow_name=workflow_name,
-                    additional_information=additional_information,
-                    send_email=send_email,
-                ),
-            ).json()
-        else:
-            response = requests.post(
-                url=self._base_url + f"/workflows/{job_id}/status",
-                headers=self._headers,
-                json=dict(
-                    metadata=metadata,
-                    status=status,
-                    workflow_name=workflow_name,
-                    additional_information=additional_information,
-                    send_email=send_email,
-                    worker_number=worker_number,
-                ),
-            )
-            return get_response(response)
+            parameters["worker_number"] = worker_number
+
+        if output:
+            parameters["output"] = {"results": output}
+
+        response = requests.post(
+            url=self._base_url + f"/workflows/{job_id}/status",
+            headers=self._headers,
+            json=parameters,
+        )
+        return get_response(response)
 
     @retry()
     def _set_field_children(
@@ -341,6 +335,31 @@ class API:
         )
         return get_response(response)
 
+    @retry()
+    def _delete_field_children(self, dataset_id: str, fieldchildren_id: str):
+        response = requests.post(
+            url=self._base_url
+            + f"/datasets/{dataset_id}/field_children/{fieldchildren_id}/delete",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _list_field_children(
+        self, dataset_id: str, page: int = 1, page_size: int = 10000, sort=None
+    ):
+        parameters = {"page": page, "page_size": page_size}
+
+        if sort:
+            parameters["sort"] = sort
+
+        response = requests.post(
+            url=self._base_url + f"/datasets/{dataset_id}/field_children/list",
+            headers=self._headers,
+            json=parameters,
+        )
+        return get_response(response)
+
     @retry()
     def _get_health(self, dataset_id: str):
         response = requests.get(
@@ -374,6 +393,23 @@ class API:
         )
         return get_response(response)
 
+    @retry()
+    def _get_temp_file_upload_url(self):
+        """Use this for temporary file uploads.
+        returns: {'download_url': ..., 'upload_url': ...}
+        """
+        response = requests.post(
+            url=self._base_url + f"/services/get_temporary_file_upload_url",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _upload_temporary_media(self, presigned_url: str, media_content: bytes):
+        return requests.put(
+            presigned_url, headers={"x-amz-tagging": "Expire=true"}, data=media_content
+        )
+
     @retry()
     def _upload_media(self, presigned_url: str, media_content: bytes):
         # dont use get response since response cannot be json decoded
@@ -549,6 +585,25 @@ class API:
         )
         return get_response(response)
 
+    @retry()
+    def _bulk_delete_keyphrase(
+        self,
+        dataset_id: str,
+        field: str,
+        alias: str,
+        ids: List[str],
+    ):
+        """
+        Update keyphrases
+        """
+        response = requests.post(
+            url=self._base_url
+            + f"/datasets/{dataset_id}/fields/{field}.{alias}/keyphrase/bulk_delete",
+            headers=self._headers,
+            json=dict(ids=ids),
+        )
+        return get_response(response)
+
     @retry()
     def _get_keyphrase(
         self, dataset_id: str, field: str, alias: str, keyphrase_id: str
@@ -556,12 +611,13 @@ class API:
         """
         Get keyphrase
         """
-        response = requests.get(
-            url=self._base_url
-            + f"/datasets/{dataset_id}/fields/{field}.{alias}/keyphrase/{keyphrase_id}/get",
-            headers=self._headers,
-        )
-        return get_response(response)
+        if isinstance(keyphrase_id, str) and keyphrase_id != "":
+            response = requests.get(
+                url=self._base_url
+                + f"/datasets/{dataset_id}/fields/{field}.{alias}/keyphrase/{keyphrase_id}/get",
+                headers=self._headers,
+            )
+            return get_response(response)
 
     @retry()
     def _delete_keyphrase(
