@@ -1,7 +1,7 @@
 import logging
 
 from inspect import Traceback
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 from workflows_core.api.api import API
 from workflows_core.dataset.dataset import Dataset
@@ -101,7 +101,9 @@ class WorkflowContextManager(API):
                 )
             else:
                 self._set_status(
-                    status=self.COMPLETE, worker_number=self._engine.worker_number
+                    status=self.COMPLETE,
+                    worker_number=self._engine.worker_number,
+                    output=self._engine.output_documents,
                 )
             if self._update_field_children:
                 for input_field in self._operator._input_fields:
@@ -115,7 +117,12 @@ class WorkflowContextManager(API):
                     )
             return True
 
-    def _set_status(self, status: str, worker_number: int = None):
+    def _set_status(
+        self,
+        status: str,
+        worker_number: int = None,
+        output: List[object] = None,
+    ):
         """
         Set the status of the workflow
         """
@@ -127,6 +134,7 @@ class WorkflowContextManager(API):
             additional_information=self._additional_information,
             send_email=self._send_email,
             worker_number=worker_number,
+            output=[] if output is None else output,
         )
         from workflows_core import __version__
 
